varying vec4 projCoord;
varying vec2 v_texCoord;

uniform vec4 Tangent;
uniform vec4 Normal;
uniform vec4 BiNormal;

uniform vec4 Eye;
varying vec3 EyeDir;

void main()
{
	vec4 realPos = gl_ModelViewMatrix * gl_Vertex;
  	projCoord = gl_TextureMatrix[1] * realPos;
	v_texCoord = gl_MultiTexCoord0.xy;
	
	// Light pass
	vec3 normal, lightDir, viewVector, halfVector;
	vec4 diffuse, ambient, globalAmbient, specular = vec4(0.0);
	float NdotL,NdotHV;
	
	/* first transform the normal into eye space and normalize the result */
	normal = normalize(gl_NormalMatrix * gl_Normal);
	
	lightDir = normalize(vec3(gl_LightSource[0].position));
	
	/* compute the cos of the angle between the normal and lights direction. 
	The light is directional so the direction is constant for every vertex.
	Since these two are normalized the cosine is the dot product. We also 
	need to clamp the result to the [0,1] range. */
	
	NdotL = max(dot(normal, lightDir), 0.0);
	
	/* Compute the diffuse, ambient and globalAmbient terms */
	diffuse = gl_FrontMaterial.diffuse * gl_LightSource[0].diffuse;
	ambient = gl_FrontMaterial.ambient * gl_LightSource[0].ambient;
	globalAmbient = gl_LightModel.ambient * gl_FrontMaterial.ambient;
	
	/* compute the specular term if NdotL is  larger than zero */
	if (NdotL > 0.0) {

		NdotHV = max(dot(normal, normalize(gl_LightSource[0].halfVector.xyz)),0.0);
		specular = gl_FrontMaterial.specular * gl_LightSource[0].specular * pow(NdotHV,gl_FrontMaterial.shininess);
	}
	
	
	gl_FrontColor = (globalAmbient + NdotL * diffuse + ambient + specular);
	gl_TexCoord[0] = gl_MultiTexCoord0;

	mat3 TBN_Matrix;  
        TBN_Matrix[0] =  gl_NormalMatrix * Tangent.xyz; 
        TBN_Matrix[1] =  gl_NormalMatrix * -BiNormal.xyz; 
        TBN_Matrix[2] =  gl_NormalMatrix * Normal.xyz; 
   
         vec4 Vertex_ModelView = gl_ModelViewMatrix * gl_Vertex; 
	 EyeDir = vec3(-Vertex_ModelView) * TBN_Matrix;      

	gl_Position = ftransform();
}